pub struct BlockHeader {
pub version: u32,
pub parents: Vec<BlockLevelParents>,
pub hash_merkle_root: Option<Hash>,
pub accepted_id_merkle_root: Option<Hash>,
pub utxo_commitment: Option<Hash>,
pub timestamp: i64,
pub bits: u32,
pub nonce: u64,
pub daa_score: u64,
pub blue_work: Vec<u8>,
pub pruning_point: Option<Hash>,
pub blue_score: u64,
}Fields
version: u32parents: Vec<BlockLevelParents>hash_merkle_root: Option<Hash>accepted_id_merkle_root: Option<Hash>utxo_commitment: Option<Hash>timestamp: i64bits: u32nonce: u64daa_score: u64blue_work: Vec<u8>pruning_point: Option<Hash>blue_score: u64Trait Implementations
Sourceimpl Clone for BlockHeader
impl Clone for BlockHeader
Sourcefn clone(&self) -> BlockHeader
fn clone(&self) -> BlockHeader
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockHeader
impl Debug for BlockHeader
Sourceimpl Default for BlockHeader
impl Default for BlockHeader
Sourceimpl From<&Header> for BlockHeader
impl From<&Header> for BlockHeader
Sourceimpl Message for BlockHeader
impl Message for BlockHeader
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BlockHeader
impl PartialEq for BlockHeader
Sourceimpl TryFrom<BlockHeader> for Header
impl TryFrom<BlockHeader> for Header
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
impl StructuralPartialEq for BlockHeader