pub struct ScriptPublicKey {
pub script: Vec<u8>,
pub version: u32,
}Fields
script: Vec<u8>version: u32Trait Implementations
Sourceimpl Clone for ScriptPublicKey
impl Clone for ScriptPublicKey
Sourcefn clone(&self) -> ScriptPublicKey
fn clone(&self) -> ScriptPublicKey
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScriptPublicKey
impl Debug for ScriptPublicKey
Sourceimpl Default for ScriptPublicKey
impl Default for ScriptPublicKey
Sourceimpl From<&ScriptPublicKey> for ScriptPublicKey
impl From<&ScriptPublicKey> for ScriptPublicKey
Sourcefn from(script_public_key: &ScriptPublicKey) -> Self
fn from(script_public_key: &ScriptPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl Message for ScriptPublicKey
impl Message for ScriptPublicKey
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ScriptPublicKey
impl PartialEq for ScriptPublicKey
Sourceimpl TryFrom<ScriptPublicKey> for ScriptPublicKey
impl TryFrom<ScriptPublicKey> for ScriptPublicKey
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
impl StructuralPartialEq for ScriptPublicKey