pub struct TransactionInput {
pub previous_outpoint: Option<Outpoint>,
pub signature_script: Vec<u8>,
pub sequence: u64,
pub sig_op_count: u32,
}Fields
previous_outpoint: Option<Outpoint>signature_script: Vec<u8>sequence: u64sig_op_count: u32Trait Implementations
Sourceimpl Clone for TransactionInput
impl Clone for TransactionInput
Sourcefn clone(&self) -> TransactionInput
fn clone(&self) -> TransactionInput
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionInput
impl Debug for TransactionInput
Sourceimpl Default for TransactionInput
impl Default for TransactionInput
Sourceimpl From<&TransactionInput> for TransactionInput
impl From<&TransactionInput> for TransactionInput
Sourcefn from(input: &TransactionInput) -> Self
fn from(input: &TransactionInput) -> Self
Converts to this type from the input type.
Sourceimpl Message for TransactionInput
impl Message for TransactionInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TransactionInput
impl PartialEq for TransactionInput
Sourceimpl TryFrom<TransactionInput> for TransactionInput
impl TryFrom<TransactionInput> for TransactionInput
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
impl StructuralPartialEq for TransactionInput