pub struct VersionMessage {
pub protocol_version: u32,
pub services: u64,
pub timestamp: i64,
pub address: Option<NetAddress>,
pub id: Vec<u8>,
pub user_agent: String,
pub disable_relay_tx: bool,
pub subnetwork_id: Option<SubnetworkId>,
pub network: String,
}Fields
protocol_version: u32services: u64timestamp: i64address: Option<NetAddress>id: Vec<u8>user_agent: Stringdisable_relay_tx: boolsubnetwork_id: Option<SubnetworkId>network: StringTrait Implementations
Sourceimpl Clone for VersionMessage
impl Clone for VersionMessage
Sourcefn clone(&self) -> VersionMessage
fn clone(&self) -> VersionMessage
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionMessage
impl Debug for VersionMessage
Sourceimpl Default for VersionMessage
impl Default for VersionMessage
Sourceimpl From<Version> for VersionMessage
impl From<Version> for VersionMessage
Sourceimpl Message for VersionMessage
impl Message for VersionMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VersionMessage
impl PartialEq for VersionMessage
Sourceimpl TryFrom<VersionMessage> for Version
impl TryFrom<VersionMessage> for Version
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
impl StructuralPartialEq for VersionMessage